@echo off 
setlocal

::
:: TARGETDIR parameter must be set to a drive letter located on boot drive 
:: (HD0). This directory is where the files needed to boot IFL will be 
:: placed when setupifl.bat is executed. From this directory a batch file
:: can then be executed to boot into IFL.
:: Example: set TARGETDIR=%userprofile%\desktop
::
set TARGETDIR=C:\IFLBOOT

::
:: IFLFILE should be set to the IFL ISO file name to use (iflnet.iso by 
:: default). This file will be looked for at the path defined by the IFLDIR 
:: parameter below, and will be used to copy IFL files from.
::
set IFLFILE=iflnet.iso

::
:: IFLDIR defines the path where the IFL ISO file defined by the IFLFILE 
:: parameter above can be found. If this variable is not set, the default
:: installation path for the IFW/IFD/IFL package is used.
:: Example: set IFLDIR=C:\Program Files (x86)\TeraByte Drive Image Backup and Restore Suite\IFL
:: Example: set IFLDIR=C:\ifl_en_gui
::
set IFLDIR=

:: 
:: IFLUN is the user name assoicated with your IFL product key. Surround
:: the value in quotes.
::
set IFLUN="Acme, Inc. (1)"

::
:: IFLPK is your IFL Product Key, required to run the registered version.
:: Example: set IFLPK=0000-1111-2222-3333-4444-5555
:: If using trial version of IFL, leave this parameter set to default.
::
set IFLPK=AAAA-BBBBB-CCCC-DDDD-EEEE-FFFF

::
:: IFLBIN is the file name for the bootfile being created in the TARGETDIR
:: defined above. This is the file that bootfile.exe will boot in order to
:: boot into IFL from Windows. This filename will have a .bin extension 
:: added automatically. 
:: Example: set IFLBIN=ifl results in a bootfile named ifl.bin, and the batch
:: file created to boot from ifl.bin will be named run_ifl.bat
::
set IFLBIN=ifl


::-----------------------------------------------------------------------------

::
:: set working drive & directory and IFL directory
::
cd /d %~dp0
if "%IFLDIR%"=="" if "%PROCESSOR_ARCHITECTURE%"=="AMD64" set IFLDIR=%ProgramFiles(x86)%\TeraByte Drive Image Backup and Restore Suite\IFL
if "%IFLDIR%"=="" set IFLDIR=%ProgramFiles%\TeraByte Drive Image Backup and Restore Suite\IFL

::
:: setup name of windows version of TBOSDT (to support older releases)
::
set TBOSDT=tbosdtw.exe
if not exist ..\win\%TBOSDT% set TBOSDT=tbosdt.exe

::
:: verify directory and files
::
for %%i in (ifl_boot ifl_boot.cfg ifl_boot.tbs setupifl.bat ifl_scripts ..\win\bootfile.exe ..\win\%TBOSDT%) do if not exist %%i goto baddir
for %%i in ("%ifldir%\%iflfile%") do if not exist %%i goto badifldir

echo.
echo Creating IFL bootfile...
echo.

::
:: create copy of original bootfile with specified file name
:: the file ifl_boot is the template bootfile
::
copy ifl_boot ifl_boot.tmp

::
:: copy iflnet.iso over from specified location
::
copy /y "%ifldir%\%iflfile%" "%iflfile%"

::
:: run the ifl_boot.tbs script and pass the Product Key and ISO file name
::
..\win\%TBOSDT% ifl_boot.tbs %iflun% %iflpk% "%iflfile%"
if errorlevel 1 goto failed

::
:: setup target directory
::
if exist "%targetdir%\." goto skipmd
md "%targetdir%" > nul
if not exist "%targetdir%\." goto badmd
:skipmd
move /y ifl_boot.tmp "%targetdir%\%iflbin%.bin" >nul
copy /y ..\win\bootfile.exe "%targetdir%" >nul
echo "%targetdir%\bootfile" "%targetdir%\%iflbin%.bin" > "%targetdir%\run_%iflbin%.bat"
start "" "%targetdir%"
echo.
echo Operation has completed.
goto end

::
:: report errors
::
:badmd
echo Unable to create target directory %targetdir%
pause
goto end

:baddir
echo This batch file must be launched from the iflsetup folder, which must
echo be a sub-folder of tbosdts_pro. The following files are required to be
echo in the iflsetup folder:
echo ifl_boot
echo ifl_boot.cfg
echo ifl_boot.tbs
echo ifl_scripts (folder)
echo The following files are required to be in the tbosdts_pro\win folder:
echo tbosdtw.exe
echo bootfile.exe
pause
goto end

:badifldir
echo Unable to find the IFL ISO file. 
echo Please check the IFLDIR and IFLFILE variables above
pause
goto end

:failed
pause
goto end

:end
if exist "%IFLFILE%" del "%IFLFILE%"
set IFLFILE=
set IFLINI=
set IFLPK=
set IFLUN=
set IFLDIR=
set TARGETDIR=
set TBOSDT=
set IFLBIN=
